@@ -114,6 +114,11 @@ def install_requirements():
         un_cmd = 'pip uninstall -r %s -yy' % (exclude_path)
         subprocess.check_call(shlex.split(un_cmd))
 
+    # Generate test-requirements files without install
+    # in order to be able to install it manually from "test_repo" option
+    full = os.path.join(home, 'full_test-requirements.txt')
+    reqgen.generate_merged_file(full, instance, requirements_name='test-requirements.txt')
+
 
 def download_files(file_list, destination):
     for src in file_list:
